@@ -1,6 +1,7 @@
 def const(v: int): return v
 # A shim for the micropython const keyword
 
+JD_VERSION = "0.0.14"
 
 JD_SERIAL_HEADER_SIZE = const(16)
 JD_SERIAL_MAX_PAYLOAD_SIZE = const(236)
@@ -23,6 +24,8 @@ JD_REGISTER_POLL_REPORT_VOLATILE_MAX_INTERVAL = 5000
 JD_REGISTER_OPTIONAL_POLL_COUNT = 3
 JD_STREAMING_DEFAULT_INTERVAL = 50
 
+JD_LOGGER_LISTENER_TIMEOUT = 3000
+
 # Registers 0x001-0x07f - r/w common to all services
 # Registers 0x080-0x0ff - r/w defined per-service
 # Registers 0x100-0x17f - r/o common to all services
@@ -39,6 +42,11 @@ CMD_EVENT_CODE_MASK = const(0xff)
 CMD_EVENT_COUNTER_MASK = const(0x7f)
 CMD_EVENT_COUNTER_POS = const(8)
 
+PIPE_PORT_SHIFT = const(7)
+PIPE_COUNTER_MASK = const(0x001f)
+PIPE_CLOSE_MASK = const(0x0020)
+PIPE_METADATA_MASK = (0x0040)
+
 
 def JD_GET(code: int):
     assert 0 <= code and code <= 0xfff
